==> tdemultimedia-R14.0.0-x86_64-ifx.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libartsbuilder.so.0 )
( cd usr/lib64 ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so.0 )
( cd usr/lib64 ; rm -rf libartsbuilder.so )
( cd usr/lib64 ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so )
( cd usr/lib64 ; rm -rf libartsmidi_idl.so.0 )
( cd usr/lib64 ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so.0 )
( cd usr/lib64 ; rm -rf libartsmidi_idl.so )
( cd usr/lib64 ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so )
( cd usr/lib64 ; rm -rf libartsmidi.so.0 )
( cd usr/lib64 ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so.0 )
( cd usr/lib64 ; rm -rf libartsmidi.so )
( cd usr/lib64 ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so )
( cd usr/lib64 ; rm -rf libartsgui_idl.so.0 )
( cd usr/lib64 ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so.0 )
( cd usr/lib64 ; rm -rf libartsgui_idl.so )
( cd usr/lib64 ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so )
( cd usr/lib64 ; rm -rf libartsgui.so.0 )
( cd usr/lib64 ; ln -sf libartsgui.so.0.0.0 libartsgui.so.0 )
( cd usr/lib64 ; rm -rf libartsgui.so )
( cd usr/lib64 ; ln -sf libartsgui.so.0.0.0 libartsgui.so )
( cd usr/lib64 ; rm -rf libartsgui_kde.so.0 )
( cd usr/lib64 ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so.0 )
( cd usr/lib64 ; rm -rf libartsgui_kde.so )
( cd usr/lib64 ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so )
( cd usr/lib64 ; rm -rf libartsmodulessynth.so.0 )
( cd usr/lib64 ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so.0 )
( cd usr/lib64 ; rm -rf libartsmodulessynth.so )
( cd usr/lib64 ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so )
( cd usr/lib64 ; rm -rf libartsmodulescommon.so.0 )
( cd usr/lib64 ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so.0 )
( cd usr/lib64 ; rm -rf libartsmodulescommon.so )
( cd usr/lib64 ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so )
( cd usr/lib64 ; rm -rf libartsmoduleseffects.so.0 )
( cd usr/lib64 ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so.0 )
( cd usr/lib64 ; rm -rf libartsmoduleseffects.so )
( cd usr/lib64 ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so )
( cd usr/lib64 ; rm -rf libartsmodulesmixers.so.0 )
( cd usr/lib64 ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so.0 )
( cd usr/lib64 ; rm -rf libartsmodulesmixers.so )
( cd usr/lib64 ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so )
( cd usr/lib64 ; rm -rf libartsmodules.so.0 )
( cd usr/lib64 ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so.0 )
( cd usr/lib64 ; rm -rf libartsmodules.so )
( cd usr/lib64 ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so )
( cd usr/lib64 ; rm -rf libartscontrolsupport.so.1 )
( cd usr/lib64 ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so.1 )
( cd usr/lib64 ; rm -rf libartscontrolsupport.so )
( cd usr/lib64 ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so )
( cd usr/lib64 ; rm -rf libartscontrolapplet.so.1 )
( cd usr/lib64 ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so.1 )
( cd usr/lib64 ; rm -rf libartscontrolapplet.so )
( cd usr/lib64 ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so )
( cd usr/lib64 ; rm -rf libarts_audiofile.so.0 )
( cd usr/lib64 ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so.0 )
( cd usr/lib64 ; rm -rf libarts_audiofile.so )
( cd usr/lib64 ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so )
( cd usr/lib64 ; rm -rf libkmidlib.so.0 )
( cd usr/lib64 ; ln -sf libkmidlib.so.0.0.0 libkmidlib.so.0 )
( cd usr/lib64 ; rm -rf libkmidlib.so )
( cd usr/lib64 ; ln -sf libkmidlib.so.0.0.0 libkmidlib.so )
( cd usr/lib64 ; rm -rf libkcddb.so.1 )
( cd usr/lib64 ; ln -sf libkcddb.so.1.0.0 libkcddb.so.1 )
( cd usr/lib64 ; rm -rf libkcddb.so )
( cd usr/lib64 ; ln -sf libkcddb.so.1.0.0 libkcddb.so )
( cd usr/lib64 ; rm -rf libmpeg.so )
( cd usr/lib64 ; ln -sf libmpeg-0.3.0.so libmpeg.so )
( cd usr/lib64 ; rm -rf libarts_xine.so.0 )
( cd usr/lib64 ; ln -sf libarts_xine.so.0.0.0 libarts_xine.so.0 )
( cd usr/lib64 ; rm -rf libarts_xine.so )
( cd usr/lib64 ; ln -sf libarts_xine.so.0.0.0 libarts_xine.so )
( cd usr/lib64 ; rm -rf libnoatun.so.1 )
( cd usr/lib64 ; ln -sf libnoatun.so.1.2.0 libnoatun.so.1 )
( cd usr/lib64 ; rm -rf libnoatun.so )
( cd usr/lib64 ; ln -sf libnoatun.so.1.2.0 libnoatun.so )
( cd usr/lib64 ; rm -rf libnoatuncontrols.so.1 )
( cd usr/lib64 ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so.1 )
( cd usr/lib64 ; rm -rf libnoatuncontrols.so )
( cd usr/lib64 ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so )
( cd usr/lib64 ; rm -rf libnoatuntags.so.1 )
( cd usr/lib64 ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so.1 )
( cd usr/lib64 ; rm -rf libnoatuntags.so )
( cd usr/lib64 ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so )
( cd usr/lib64 ; rm -rf libaudiocdplugins.so.1 )
( cd usr/lib64 ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so.1 )
( cd usr/lib64 ; rm -rf libaudiocdplugins.so )
( cd usr/lib64 ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so )
( cd usr/lib64 ; rm -rf libarts_mpeglib-0.3.0.so.0 )
( cd usr/lib64 ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib-0.3.0.so.0 )
( cd usr/lib64 ; rm -rf libarts_mpeglib.so )
( cd usr/lib64 ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib.so )
( cd usr/lib64 ; rm -rf libarts_splay.so.0 )
( cd usr/lib64 ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so.0 )
( cd usr/lib64 ; rm -rf libarts_splay.so )
( cd usr/lib64 ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so )
( cd usr/share/doc/tde/HTML/en/artsbuilder ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/artsbuilder ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/juk ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/juk ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kaboodle ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kaboodle ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kaudiocreator ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kaudiocreator ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kmid ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kmid ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kmix ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kmix ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/krec ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/krec ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kscd ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kscd ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/noatun ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/noatun ; ln -sf /usr/share/doc/tde/HTML/en/common common )

==> tdemultimedia-14.0.9-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/lib64 ; rm -rf libarts_akode.so )
( cd usr/lib64 ; ln -sf libarts_akode.so.0.0.0 libarts_akode.so )
( cd usr/lib64 ; rm -rf libarts_akode.so.0 )
( cd usr/lib64 ; ln -sf libarts_akode.so.0.0.0 libarts_akode.so.0 )
( cd usr/lib64 ; rm -rf libarts_audiofile.so )
( cd usr/lib64 ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so )
( cd usr/lib64 ; rm -rf libarts_audiofile.so.0 )
( cd usr/lib64 ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so.0 )
( cd usr/lib64 ; rm -rf libarts_mpeglib-0.3.0.so.0 )
( cd usr/lib64 ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib-0.3.0.so.0 )
( cd usr/lib64 ; rm -rf libarts_mpeglib.so )
( cd usr/lib64 ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib.so )
( cd usr/lib64 ; rm -rf libarts_splay.so )
( cd usr/lib64 ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so )
( cd usr/lib64 ; rm -rf libarts_splay.so.0 )
( cd usr/lib64 ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so.0 )
( cd usr/lib64 ; rm -rf libarts_xine.so )
( cd usr/lib64 ; ln -sf libarts_xine.so.0.0.0 libarts_xine.so )
( cd usr/lib64 ; rm -rf libarts_xine.so.0 )
( cd usr/lib64 ; ln -sf libarts_xine.so.0.0.0 libarts_xine.so.0 )
( cd usr/lib64 ; rm -rf libartsbuilder.so )
( cd usr/lib64 ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so )
( cd usr/lib64 ; rm -rf libartsbuilder.so.0 )
( cd usr/lib64 ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so.0 )
( cd usr/lib64 ; rm -rf libartscontrolapplet.so )
( cd usr/lib64 ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so )
( cd usr/lib64 ; rm -rf libartscontrolapplet.so.1 )
( cd usr/lib64 ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so.1 )
( cd usr/lib64 ; rm -rf libartscontrolsupport.so )
( cd usr/lib64 ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so )
( cd usr/lib64 ; rm -rf libartscontrolsupport.so.1 )
( cd usr/lib64 ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so.1 )
( cd usr/lib64 ; rm -rf libartsgui.so )
( cd usr/lib64 ; ln -sf libartsgui.so.0.0.0 libartsgui.so )
( cd usr/lib64 ; rm -rf libartsgui.so.0 )
( cd usr/lib64 ; ln -sf libartsgui.so.0.0.0 libartsgui.so.0 )
( cd usr/lib64 ; rm -rf libartsgui_idl.so )
( cd usr/lib64 ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so )
( cd usr/lib64 ; rm -rf libartsgui_idl.so.0 )
( cd usr/lib64 ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so.0 )
( cd usr/lib64 ; rm -rf libartsgui_kde.so )
( cd usr/lib64 ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so )
( cd usr/lib64 ; rm -rf libartsgui_kde.so.0 )
( cd usr/lib64 ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so.0 )
( cd usr/lib64 ; rm -rf libartsmidi.so )
( cd usr/lib64 ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so )
( cd usr/lib64 ; rm -rf libartsmidi.so.0 )
( cd usr/lib64 ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so.0 )
( cd usr/lib64 ; rm -rf libartsmidi_idl.so )
( cd usr/lib64 ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so )
( cd usr/lib64 ; rm -rf libartsmidi_idl.so.0 )
( cd usr/lib64 ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so.0 )
( cd usr/lib64 ; rm -rf libartsmodules.so )
( cd usr/lib64 ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so )
( cd usr/lib64 ; rm -rf libartsmodules.so.0 )
( cd usr/lib64 ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so.0 )
( cd usr/lib64 ; rm -rf libartsmodulescommon.so )
( cd usr/lib64 ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so )
( cd usr/lib64 ; rm -rf libartsmodulescommon.so.0 )
( cd usr/lib64 ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so.0 )
( cd usr/lib64 ; rm -rf libartsmoduleseffects.so )
( cd usr/lib64 ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so )
( cd usr/lib64 ; rm -rf libartsmoduleseffects.so.0 )
( cd usr/lib64 ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so.0 )
( cd usr/lib64 ; rm -rf libartsmodulesmixers.so )
( cd usr/lib64 ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so )
( cd usr/lib64 ; rm -rf libartsmodulesmixers.so.0 )
( cd usr/lib64 ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so.0 )
( cd usr/lib64 ; rm -rf libartsmodulessynth.so )
( cd usr/lib64 ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so )
( cd usr/lib64 ; rm -rf libartsmodulessynth.so.0 )
( cd usr/lib64 ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so.0 )
( cd usr/lib64 ; rm -rf libaudiocdplugins.so )
( cd usr/lib64 ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so )
( cd usr/lib64 ; rm -rf libaudiocdplugins.so.1 )
( cd usr/lib64 ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so.1 )
( cd usr/lib64 ; rm -rf libkcddb.so )
( cd usr/lib64 ; ln -sf libkcddb.so.1.0.0 libkcddb.so )
( cd usr/lib64 ; rm -rf libkcddb.so.1 )
( cd usr/lib64 ; ln -sf libkcddb.so.1.0.0 libkcddb.so.1 )
( cd usr/lib64 ; rm -rf libmpeg.so )
( cd usr/lib64 ; ln -sf libmpeg-0.3.0.so libmpeg.so )
( cd usr/lib64 ; rm -rf libnoatun.so )
( cd usr/lib64 ; ln -sf libnoatun.so.1.2.0 libnoatun.so )
( cd usr/lib64 ; rm -rf libnoatun.so.1 )
( cd usr/lib64 ; ln -sf libnoatun.so.1.2.0 libnoatun.so.1 )
( cd usr/lib64 ; rm -rf libnoatuncontrols.so )
( cd usr/lib64 ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so )
( cd usr/lib64 ; rm -rf libnoatuncontrols.so.1 )
( cd usr/lib64 ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so.1 )
( cd usr/lib64 ; rm -rf libnoatuntags.so )
( cd usr/lib64 ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so )
( cd usr/lib64 ; rm -rf libnoatuntags.so.1 )
( cd usr/lib64 ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so.1 )
( cd usr/lib64 ; rm -rf libtdemidlib.so )
( cd usr/lib64 ; ln -sf libtdemidlib.so.0.0.0 libtdemidlib.so )
( cd usr/lib64 ; rm -rf libtdemidlib.so.0 )
( cd usr/lib64 ; ln -sf libtdemidlib.so.0.0.0 libtdemidlib.so.0 )
( cd usr/share/doc/tde/HTML/en/artsbuilder ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/artsbuilder ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/juk ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/juk ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kaboodle ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kaboodle ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kaudiocreator ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kaudiocreator ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/audiocd ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/audiocd ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kcontrol/cddb ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kcontrol/cddb ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kmix ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kmix ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/krec ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/krec ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kscd ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kscd ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/noatun ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/noatun ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdeioslave/audiocd ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdeioslave/audiocd ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdemid ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdemid ; ln -sf /usr/share/doc/tde/HTML/en/common common )
